@@ -26,6 +26,7 @@
 #include "mainwindow.h"
 #include "batchextract.h"
 #include "addtoarchive.h"
+#include "pluginmanager.h"
 
 #include <QApplication>
 #include <QCommandLineParser>
@@ -93,7 +94,7 @@ int main(int argc, char **argv)
                          QStringLiteral(ARK_VERSION_STRING),
                          i18n("KDE Archiving tool"),
                          KAboutLicense::GPL,
-                         i18n("(c) 1997-2017, The Ark Developers"),
+                         i18n("(c) 1997-2018, The Ark Developers"),
                          QString(),
                          QStringLiteral("http://utils.kde.org/projects/ark")
     );
@@ -193,6 +194,9 @@ int main(int argc, char **argv)
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("a") << QStringLiteral("autosubfolder"),
                                         i18n("Archive contents will be read, and if detected to not be a single folder archive, a subfolder with the name of the archive will be created.")));
 
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("m") << QStringLiteral("mimetypes"),
+                                        i18n("List supported MIME types.")));
+
     aboutData.setupCommandLine(&parser);
 
     // Do the command line parsing.
@@ -301,6 +305,16 @@ int main(int argc, char **argv)
 
             batchJob->start();
 
+        } else if (parser.isSet(QStringLiteral("mimetypes"))) {
+
+            Kerfuffle::PluginManager pluginManager;
+            const auto mimeTypes = pluginManager.supportedMimeTypes();
+            QTextStream cout(stdout);
+            for (const auto &mimeType : mimeTypes) {
+                cout << mimeType << '\n';
+            }
+            return 0;
+
         } else {
 
             MainWindow *window = new MainWindow;
