@@ -110,7 +110,7 @@ public:
      * Returns count of required finish signals for a job to be finished.
      *
      * These two methods are used by move and copy jobs, which in some plugins implementations have to call
-     * several processes sequentually. For instance, moving entries in zip archive is only possible if
+     * several processes sequentially. For instance, moving entries in zip archive is only possible if
      * extracting the entries, deleting them, recreating destination folder structure and adding them back again.
      */
     virtual int moveRequiredSignals() const;
@@ -168,7 +168,7 @@ public:
      */
     virtual bool hasBatchExtractionProgress() const;
 
-signals:
+Q_SIGNALS:
 
     /**
      * Emitted when the user cancels the operation. Examples:
@@ -214,7 +214,7 @@ private:
     bool m_isCorrupt;
     bool m_isMultiVolume;
 
-private slots:
+private Q_SLOTS:
     void onEntry(Archive::Entry *archiveEntry);
 };
 
@@ -223,7 +223,15 @@ class KERFUFFLE_EXPORT ReadWriteArchiveInterface: public ReadOnlyArchiveInterfac
     Q_OBJECT
 public:
     enum OperationMode  {
-        List, Extract, Add, Move, Copy, Delete, Comment, Test
+        NoOperation,
+        List,
+        Extract,
+        Add,
+        Move,
+        Copy,
+        Delete,
+        Comment,
+        Test
     };
 
     explicit ReadWriteArchiveInterface(QObject *parent, const QVariantList &args);
@@ -246,10 +254,10 @@ public:
     virtual bool deleteFiles(const QVector<Archive::Entry*> &files) = 0;
     virtual bool addComment(const QString &comment) = 0;
 
-signals:
+Q_SIGNALS:
     void entryRemoved(const QString &path);
 
-private slots:
+private Q_SLOTS:
     void onEntryRemoved(const QString &path);
 };
 
