@@ -27,6 +27,7 @@
  */
 
 #include "readwritelibarchiveplugin.h"
+#include "ark_debug.h"
 
 #include <KLocalizedString>
 #include <KPluginFactory>
@@ -35,6 +36,8 @@
 #include <QSaveFile>
 #include <QThread>
 
+#include <archive_entry.h>
+
 K_PLUGIN_FACTORY_WITH_JSON(ReadWriteLibarchivePluginFactory, "kerfuffle_libarchive.json", registerPlugin<ReadWriteLibarchivePlugin>();)
 
 ReadWriteLibarchivePlugin::ReadWriteLibarchivePlugin(QObject *parent, const QVariantList &args)
@@ -66,9 +69,9 @@ bool ReadWriteLibarchivePlugin::addFiles(const QVector<Archive::Entry*> &files,
 
     // First write the new files.
     qCDebug(ARK) << "Writing new entries";
-    int no_entries = 0;
+    uint no_entries = 0;
     // Recreate destination directory structure.
-    const QString destinationPath = (destination == Q_NULLPTR)
+    const QString destinationPath = (destination == nullptr)
                                     ? QString()
                                     : destination->fullPath();
 
@@ -149,7 +152,7 @@ bool ReadWriteLibarchivePlugin::moveFiles(const QVector<Archive::Entry*> &files,
     }
 
     // Copy old elements from previous archive to new archive.
-    int no_entries = 0;
+    uint no_entries = 0;
     m_filesPaths = entryFullPaths(files);
     m_entriesWithoutChildren = entriesWithoutChildren(files).count();
     m_destination = destination;
@@ -179,7 +182,7 @@ bool ReadWriteLibarchivePlugin::copyFiles(const QVector<Archive::Entry*> &files,
     }
 
     // Copy old elements from previous archive to new archive.
-    int no_entries = 0;
+    uint no_entries = 0;
     m_filesPaths = entryFullPaths(files);
     m_destination = destination;
     const bool isSuccessful = processOldEntries(no_entries, Copy, m_numberOfEntries);
@@ -206,7 +209,7 @@ bool ReadWriteLibarchivePlugin::deleteFiles(const QVector<Archive::Entry*> &file
     }
 
     // Copy old elements from previous archive to new archive.
-    int no_entries = 0;
+    uint no_entries = 0;
     m_filesPaths = entryFullPaths(files);
     const bool isSuccessful = processOldEntries(no_entries, Delete, m_numberOfEntries);
     if (isSuccessful) {
@@ -288,10 +291,13 @@ bool ReadWriteLibarchivePlugin::initializeWriterFilters()
         ret = archive_write_add_filter_lrzip(m_archiveWriter.data());
         requiresExecutable = true;
         break;
-#ifdef HAVE_LIBARCHIVE_3_2_0
     case ARCHIVE_FILTER_LZ4:
         ret = archive_write_add_filter_lz4(m_archiveWriter.data());
         break;
+#ifdef HAVE_ZSTD_SUPPORT
+    case ARCHIVE_FILTER_ZSTD:
+        ret = archive_write_add_filter_zstd(m_archiveWriter.data());
+        break;
 #endif
     case ARCHIVE_FILTER_NONE:
         ret = archive_write_add_filter_none(m_archiveWriter.data());
@@ -342,10 +348,13 @@ bool ReadWriteLibarchivePlugin::initializeNewFileWriterFilters(const Compression
         qCDebug(ARK) << "Detected lrzip compression for new file";
         ret = archive_write_add_filter_lrzip(m_archiveWriter.data());
         requiresExecutable = true;
-#ifdef HAVE_LIBARCHIVE_3_2_0
-        } else if (filename().right(3).toUpper() == QLatin1String("LZ4")) {
-            qCDebug(ARK) << "Detected lz4 compression for new file";
-            ret = archive_write_add_filter_lz4(m_archiveWriter.data());
+    } else if (filename().right(3).toUpper() == QLatin1String("LZ4")) {
+        qCDebug(ARK) << "Detected lz4 compression for new file";
+        ret = archive_write_add_filter_lz4(m_archiveWriter.data());
+#ifdef HAVE_ZSTD_SUPPORT
+    } else if (filename().rightRef(3).compare(QLatin1String("zst"), Qt::CaseInsensitive)) {
+        qCDebug(ARK) << "Detected zstd compression for new file";
+        ret = archive_write_add_filter_zstd(m_archiveWriter.data());
 #endif
     } else if (filename().right(3).toUpper() == QLatin1String("TAR")) {
         qCDebug(ARK) << "Detected no compression for new file (pure tar)";
@@ -366,7 +375,7 @@ bool ReadWriteLibarchivePlugin::initializeNewFileWriterFilters(const Compression
     // Set compression level if passed in CompressionOptions.
     if (options.isCompressionLevelSet()) {
         qCDebug(ARK) << "Using compression level:" << options.compressionLevel();
-        ret = archive_write_set_filter_option(m_archiveWriter.data(), NULL, "compression-level", QString::number(options.compressionLevel()).toUtf8());
+        ret = archive_write_set_filter_option(m_archiveWriter.data(), nullptr, "compression-level", QString::number(options.compressionLevel()).toUtf8().constData());
         if (ret != ARCHIVE_OK) {
             qCWarning(ARK) << "Failed to set compression level" << archive_error_string(m_archiveWriter.data());
             emit error(i18nc("@info", "Could not set the compression level."));
@@ -386,13 +395,13 @@ void ReadWriteLibarchivePlugin::finish(const bool isSuccessful)
     m_tempFile.commit();
 }
 
-bool ReadWriteLibarchivePlugin::processOldEntries(int &entriesCounter, OperationMode mode, uint totalCount)
+bool ReadWriteLibarchivePlugin::processOldEntries(uint &entriesCounter, OperationMode mode, uint totalCount)
 {
     struct archive_entry *entry;
 
     const uint newEntries = entriesCounter;
     entriesCounter = 0;
-    int iteratedEntries = 0;
+    uint iteratedEntries = 0;
 
     // Create a map that contains old path as key and new path as value.
     QMap<QString, QString> pathMap;
@@ -426,7 +435,7 @@ bool ReadWriteLibarchivePlugin::processOldEntries(int &entriesCounter, Operation
                 iteratedEntries--;
 
                 // Change entry path.
-                archive_entry_set_pathname(entry, newPathname.toUtf8());
+                archive_entry_set_pathname(entry, newPathname.toUtf8().constData());
                 emitEntryFromArchiveEntry(entry);
             }
         } else if (m_filesPaths.contains(file)) {
@@ -508,7 +517,7 @@ bool ReadWriteLibarchivePlugin::writeFile(const QString &relativeName, const QSt
     //          which case stat() will be called. To avoid this, we
     //          call lstat() ourselves.
     struct stat st;
-    lstat(QFile::encodeName(absoluteFilename).constData(), &st);
+    lstat(QFile::encodeName(absoluteFilename).constData(), &st); // krazy:exclude=syscalls
 
     struct archive_entry *entry = archive_entry_new();
     archive_entry_set_pathname(entry, QFile::encodeName(destinationFilename).constData());
