@@ -60,13 +60,14 @@ private:
     void progressEmitted(double pct);
     QString permissionsToString(const mode_t &perm);
     void setOperationMode(OperationMode operationMode);
+    static void progressCallback(zip_t *, double progress, void *that);
 
     QVector<Archive::Entry*> m_emittedEntries;
     bool m_overwriteAll;
     bool m_skipAll;
     bool m_listAfterAdd;
     QMutex m_mutex;
-    OperationMode m_operationMode = List;
+    OperationMode m_operationMode = NoOperation;
 };
 
 #endif // LIBZIPPLUGIN_H
